@@ -21,11 +21,11 @@ use self::windows_imports::*;
 
 use cssparser::{_cssparser_internal_to_lowercase, match_ignore_ascii_case};
 
-use librsvg::rsvg_convert_only::{
+use rsvg::rsvg_convert_only::{
     AspectRatio, CssLength, Dpi, Horizontal, LegacySize, Length, Normalize, NormalizeParams, Parse,
     PathOrUrl, Rect, Signed, ULength, Unsigned, Validate, Vertical, ViewBox,
 };
-use librsvg::{AcceptLanguage, CairoRenderer, Color, Language, LengthUnit, Loader, RenderingError};
+use rsvg::{AcceptLanguage, CairoRenderer, Color, Language, LengthUnit, Loader, RenderingError};
 
 use std::ffi::OsString;
 use std::io;
