@@ -3,7 +3,7 @@ use markup5ever::{expanded_name, local_name, namespace_url, ns};
 
 use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
-use crate::element::{set_attribute, SetAttributes};
+use crate::element::{set_attribute, ElementTrait};
 use crate::error::*;
 use crate::node::{CascadedValues, Node};
 use crate::parsers::{Parse, ParseValue};
@@ -59,7 +59,7 @@ pub struct Blend {
     color_interpolation_filters: ColorInterpolationFilters,
 }
 
-impl SetAttributes for FeBlend {
+impl ElementTrait for FeBlend {
     fn set_attributes(&mut self, attrs: &Attributes, session: &Session) {
         let (in1, in2) = self.base.parse_two_inputs(attrs, session);
         self.params.in1 = in1;
