@@ -2,11 +2,11 @@ use std::cmp::min;
 use std::f64;
 
 use markup5ever::{expanded_name, local_name, namespace_url, ns};
-use nalgebra::{DMatrix, Dynamic, VecStorage};
+use nalgebra::{DMatrix, Dyn, VecStorage};
 
 use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
-use crate::element::{set_attribute, SetAttributes};
+use crate::element::{set_attribute, ElementTrait};
 use crate::node::{CascadedValues, Node};
 use crate::parsers::{NumberOptionalNumber, ParseValue};
 use crate::properties::ColorInterpolationFilters;
@@ -56,7 +56,7 @@ impl Default for GaussianBlur {
     }
 }
 
-impl SetAttributes for FeGaussianBlur {
+impl ElementTrait for FeGaussianBlur {
     fn set_attributes(&mut self, attrs: &Attributes, session: &Session) {
         self.params.in1 = self.base.parse_one_input(attrs, session);
 
@@ -183,11 +183,7 @@ fn gaussian_blur(
     } else {
         (1, kernel.len())
     };
-    let kernel = DMatrix::from_data(VecStorage::new(
-        Dynamic::new(rows),
-        Dynamic::new(cols),
-        kernel,
-    ));
+    let kernel = DMatrix::from_data(VecStorage::new(Dyn(rows), Dyn(cols), kernel));
 
     Ok(input_surface.convolve(
         bounds,
