@@ -5,11 +5,11 @@ use markup5ever::{expanded_name, local_name, namespace_url, ns};
 use crate::aspect_ratio::AspectRatio;
 use crate::bbox::BoundingBox;
 use crate::document::AcquiredNodes;
-use crate::drawing_ctx::DrawingCtx;
-use crate::element::{set_attribute, Draw, SetAttributes};
+use crate::drawing_ctx::{DrawingCtx, Viewport};
+use crate::element::{set_attribute, ElementTrait};
 use crate::error::*;
 use crate::href::{is_href, set_href};
-use crate::layout::{self, StackingContext};
+use crate::layout::{self, Layer, LayerKind, StackingContext};
 use crate::length::*;
 use crate::node::{CascadedValues, Node, NodeBorrow};
 use crate::parsers::ParseValue;
@@ -27,7 +27,7 @@ pub struct Image {
     href: Option<String>,
 }
 
-impl SetAttributes for Image {
+impl ElementTrait for Image {
     fn set_attributes(&mut self, attrs: &Attributes, session: &Session) {
         for (attr, value) in attrs.iter() {
             match attr.expanded() {
@@ -44,14 +44,13 @@ impl SetAttributes for Image {
             }
         }
     }
-}
 
-impl Draw for Image {
     fn draw(
         &self,
         node: &Node,
         acquired_nodes: &mut AcquiredNodes<'_>,
         cascaded: &CascadedValues<'_>,
+        viewport: &Viewport,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
     ) -> Result<BoundingBox, RenderingError> {
@@ -73,8 +72,7 @@ impl Draw for Image {
 
         let values = cascaded.get();
 
-        let view_params = draw_ctx.get_view_params();
-        let params = NormalizeParams::new(values, &view_params);
+        let params = NormalizeParams::new(values, viewport);
 
         let x = values.x().0.to_user(&params);
         let y = values.y().0.to_user(&params);
@@ -94,13 +92,13 @@ impl Draw for Image {
 
         let overflow = values.overflow();
 
-        let image = layout::Image {
+        let image = Box::new(layout::Image {
             surface,
             is_visible,
             rect,
             aspect: self.aspect,
             overflow,
-        };
+        });
 
         let elt = node.borrow_element();
         let stacking_ctx = StackingContext::new(
@@ -111,6 +109,11 @@ impl Draw for Image {
             values,
         );
 
-        draw_ctx.draw_image(&image, &stacking_ctx, acquired_nodes, values, clipping)
+        let layer = Layer {
+            kind: LayerKind::Image(image),
+            stacking_ctx,
+        };
+
+        draw_ctx.draw_layer(&layer, acquired_nodes, clipping, viewport)
     }
 }
