@@ -5,14 +5,13 @@ use markup5ever::{expanded_name, local_name, namespace_url, ns};
 use crate::aspect_ratio::*;
 use crate::coord_units::CoordUnits;
 use crate::document::{AcquiredNode, AcquiredNodes, NodeId, NodeStack};
-use crate::drawing_ctx::ViewParams;
+use crate::drawing_ctx::Viewport;
 use crate::element::{set_attribute, ElementData, ElementTrait};
 use crate::error::*;
 use crate::href::{is_href, set_href};
 use crate::length::*;
 use crate::node::{Node, NodeBorrow, WeakNode};
 use crate::parsers::ParseValue;
-use crate::properties::ComputedValues;
 use crate::rect::Rect;
 use crate::session::Session;
 use crate::transform::{Transform, TransformAttribute};
@@ -354,13 +353,13 @@ impl ResolvedPattern {
     pub fn to_user_space(
         &self,
         object_bbox: &Option<Rect>,
-        current_params: &ViewParams,
-        values: &ComputedValues,
+        viewport: &Viewport,
+        values: &NormalizeValues,
     ) -> Option<UserSpacePattern> {
         let node_with_children = self.node_with_children()?;
 
-        let view_params = current_params.with_units(self.units.0);
-        let params = NormalizeParams::new(values, &view_params);
+        let view_params = viewport.with_units(self.units.0);
+        let params = NormalizeParams::from_values(values, &view_params);
 
         let rect = self.get_rect(&params);
 
