@@ -484,7 +484,6 @@ make_properties! {
         // "transform-box"            => (PresentationAttr::Yes, unimplemented),
         // "transform-origin"         => (PresentationAttr::Yes, unimplemented),
         "unicode-bidi"                => (PresentationAttr::Yes, unicode_bidi                : UnicodeBidi),
-        // "vector-effect"            => (PresentationAttr::Yes, unimplemented),
         "visibility"                  => (PresentationAttr::Yes, visibility                  : Visibility),
         // "white-space"              => (PresentationAttr::Yes, unimplemented),
         // "word-spacing"             => (PresentationAttr::Yes, unimplemented),
@@ -501,6 +500,7 @@ make_properties! {
         "mix-blend-mode"              => (PresentationAttr::No,  mix_blend_mode              : MixBlendMode),
         "paint-order"                 => (PresentationAttr::Yes, paint_order                 : PaintOrder),
         "text-orientation"            => (PresentationAttr::No,  text_orientation            : TextOrientation),
+        "vector-effect"               => (PresentationAttr::Yes, vector_effect               : VectorEffect),
     }
 
     // These are not properties, but presentation attributes.  However,
@@ -750,6 +750,7 @@ impl SpecifiedValues {
         compute!(TextRendering, text_rendering);
         compute!(TransformProperty, transform_property);
         compute!(UnicodeBidi, unicode_bidi);
+        compute!(VectorEffect, vector_effect);
         compute!(Visibility, visibility);
         compute!(Width, width);
         compute!(WritingMode, writing_mode);
@@ -891,11 +892,7 @@ impl SpecifiedValues {
         }
     }
 
-    pub fn parse_presentation_attributes(
-        &mut self,
-        session: &Session,
-        attrs: &Attributes,
-    ) -> Result<(), ElementError> {
+    pub fn parse_presentation_attributes(&mut self, session: &Session, attrs: &Attributes) {
         for (attr, value) in attrs.iter() {
             match attr.expanded() {
                 expanded_name!("", "transform") => {
@@ -911,25 +908,41 @@ impl SpecifiedValues {
                     // xml:lang is a non-presentation attribute and as such cannot have the
                     // "inherit" value.  So, we don't call parse_one_presentation_attribute()
                     // for it, but rather call its parser directly.
-                    self.set_parsed_property(&ParsedProperty::XmlLang(SpecifiedValue::Specified(
-                        attr.parse(value)?,
-                    )));
+                    let parse_result: Result<XmlLang, _> = attr.parse(value);
+                    match parse_result {
+                        Ok(lang) => {
+                            self.set_parsed_property(&ParsedProperty::XmlLang(
+                                SpecifiedValue::Specified(lang),
+                            ));
+                        }
+
+                        Err(e) => {
+                            rsvg_log!(session, "ignoring attribute with invalid value: {}", e);
+                        }
+                    }
                 }
 
                 expanded_name!(xml "space") => {
                     // xml:space is a non-presentation attribute and as such cannot have the
                     // "inherit" value.  So, we don't call parse_one_presentation_attribute()
                     // for it, but rather call its parser directly.
-                    self.set_parsed_property(&ParsedProperty::XmlSpace(SpecifiedValue::Specified(
-                        attr.parse(value)?,
-                    )));
+                    let parse_result: Result<XmlSpace, _> = attr.parse(value);
+                    match parse_result {
+                        Ok(space) => {
+                            self.set_parsed_property(&ParsedProperty::XmlSpace(
+                                SpecifiedValue::Specified(space),
+                            ));
+                        }
+
+                        Err(e) => {
+                            rsvg_log!(session, "ignoring attribute with invalid value: {}", e);
+                        }
+                    }
                 }
 
                 _ => self.parse_one_presentation_attribute(session, attr, value),
             }
         }
-
-        Ok(())
     }
 
     pub fn set_property_from_declaration(
@@ -959,7 +972,7 @@ impl SpecifiedValues {
         origin: Origin,
         important_styles: &mut HashSet<QualName>,
         session: &Session,
-    ) -> Result<(), ElementError> {
+    ) {
         let mut input = ParserInput::new(declarations);
         let mut parser = Parser::new(&mut input);
 
@@ -972,8 +985,6 @@ impl SpecifiedValues {
                 }
             })
             .for_each(|decl| self.set_property_from_declaration(&decl, origin, important_styles));
-
-        Ok(())
     }
 }
 
@@ -1117,13 +1128,4 @@ mod tests {
 
         assert_eq!(computed.opacity(), half_opacity.clone());
     }
-
-    #[test]
-    fn empty_style_attribute_parses_ok() {
-        let mut specified = SpecifiedValues::default();
-
-        assert!(specified
-            .parse_style_declarations("", Origin::Author, &mut HashSet::new(), &Session::default())
-            .is_ok())
-    }
 }
